@@ -10,7 +10,6 @@ from liionpack.solver_utils import _mapped_eval as me
 import ray
 import numpy as np
 import time as ticker
-from dask.distributed import Client
 from tqdm import tqdm
 import pybamm
 
@@ -683,111 +682,3 @@ class CasadiManager(GenericManager):
 
     def cleanup(self):
         pass
-
-
-class DaskManager(GenericManager):
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
-
-    def split_models(self, Nspm, nproc):
-        # Manage the number of SPM models per worker
-        self.split_index = np.array_split(np.arange(Nspm), nproc)
-        self.spm_per_worker = [len(s) for s in self.split_index]
-        self.slices = []
-        for i in range(nproc):
-            self.slices.append(
-                slice(self.split_index[i][0], self.split_index[i][-1] + 1)
-            )
-
-    def setup_actors(self, nproc, inputs, initial_soc):
-        # Set up a casadi actor on each process
-        lp.logger.notice("Dask initialization started")
-        self.client = Client(n_workers=nproc)
-        lp.logger.notice("Dask initialization complete")
-        tic = ticker.time()
-        futures = []
-        for i in range(nproc):
-            # Create actor on each worker containing a simulation
-            futures.append(self.client.submit(GenericActor, actor=True, pure=False))
-        self.actors = [af.result() for af in futures]
-        futures = []
-        for i, a in enumerate(self.actors):
-            futures.append(
-                a.setup(
-                    Nspm=self.spm_per_worker[i],
-                    sim_func=self.sim_func,
-                    parameter_values=self.parameter_values,
-                    inputs=inputs[self.slices[i]],
-                    dt=self.dt,
-                    variable_names=self.variable_names,
-                    initial_soc=initial_soc,
-                    nproc=1,
-                )
-            )
-
-        _ = [af.result() for af in futures]
-        toc = ticker.time()
-        lp.logger.info(
-            "Dask actors setup in time " + str(np.around(toc - tic, 3)) + "s"
-        )
-
-    def step_actors(self):
-        tic = ticker.time()
-        inputs = self.build_inputs()
-        future_steps = []
-        for i, a in enumerate(self.actors):
-            future_steps.append(a.step(inputs=inputs[i]))
-        events = [af.result() for af in future_steps]
-        if np.any(events):
-            self.log_event()
-        toc = ticker.time()
-        lp.logger.info(
-            "Dask actors stepped in time " + str(np.around(toc - tic, 3)) + "s"
-        )
-
-    def evaluate_actors(self):
-        tic = ticker.time()
-        inputs = self.build_inputs()
-        future_evals = []
-        for i, a in enumerate(self.actors):
-            future_evals.append(a.evaluate(inputs=inputs[i]))
-        _ = [af.result() for af in future_evals]
-        toc = ticker.time()
-        lp.logger.info(
-            "Dask actors evaluated in time " + str(np.around(toc - tic, 3)) + "s"
-        )
-
-    def get_actor_output(self, step):
-        tic = ticker.time()
-        future_gets = []
-        for i, a in enumerate(self.actors):
-            future_gets.append(a.output())
-        for i, fg in enumerate(future_gets):
-            out = fg.result()
-            self.output[:, step, self.split_index[i]] = out
-        toc = ticker.time()
-        lp.logger.info(
-            "Dask,actors output got in time " + str(np.around(toc - tic, 3)) + "s"
-        )
-
-    def log_event(self):
-        futures = []
-        for actor in self.actors:
-            futures.append(actor.get_event_change())
-        all_event_changes = []
-        for i, f in enumerate(futures):
-            all_event_changes.append(np.asarray(f.result()))
-        event_change = np.hstack(all_event_changes)
-        Nr, Nc = event_change.shape
-        event_names = self.actors[0].get_event_names().result()
-        for r in range(Nr):
-            if np.any(event_change[r, :]):
-                lp.logger.warning(
-                    event_names[r]
-                    + ", Batteries: "
-                    + str(np.where(event_change[r, :])[0].tolist())
-                )
-
-    def cleanup(self):
-        lp.logger.notice("Shutting down Dask client")
-        self.client.shutdown()
